@@ -168,6 +168,31 @@ class ByteStringWrapper(CustomStringRepresentation):
         return self.string.__format__(spec)
 
 
+def is_valid_variable_name(name: str) -> bool:
+    """
+    All single-letter, uppercase variable names are reserved.
+    """
+    if len(name) == 1 and name.upper() == name:
+        return False
+    if not name.isidentifier():
+        return False
+    return True
+
+
+def check_variable_name(name: Optional[str]) -> Optional[str]:
+    """
+    All single-letter, uppercase variable names are reserved.
+    """
+    if name is None:
+        return None
+    elif is_valid_variable_name(name):
+        return name
+    raise ValueError(
+        F'The variable name {name!r} is invalid: Variable names must be identifiers. Additionally, single uppercase '
+        R'letters are reserved for internal use.'
+    )
+
+
 class SizeInt(int, CustomStringRepresentation):
     """
     The string representation of this int class is a a human-readable expression of size, using
@@ -225,7 +250,7 @@ COMMON_PROPERTIES: Dict[str, Callable[[ByteString], Union[str, int, float]]] = {
     'size'    : lambda chunk: SizeInt(len(chunk)),
     'entropy' : lambda chunk: Percentage(entropy(chunk)),
     'ic'      : lambda chunk: Percentage(index_of_coincidence(chunk)),
-    'crc32'   : lambda chunk: F'{zlib.crc32(chunk)&0xFFFFFFFF:08X}',
+    'crc32'   : lambda chunk: HexByteString((zlib.crc32(chunk) & 0xFFFFFFFF).to_bytes(4, 'big')),
     'sha1'    : lambda chunk: HexByteString(hashlib.sha1(chunk).digest()),
     'sha256'  : lambda chunk: HexByteString(hashlib.sha256(chunk).digest()),
     'md5'     : lambda chunk: HexByteString(hashlib.md5(chunk).digest()),
@@ -250,21 +275,44 @@ class LazyMetaOracle(dict):
         'sha1'    : HexByteString,
         'sha256'  : HexByteString,
         'md5'     : HexByteString,
+        'crc32'   : HexByteString,
     }
 
-    def __init__(self, chunk: ByteString, ghost: bool = False, alias: Optional[Dict[str, str]] = None, *init):
-        super().__init__(*init)
-        self.alias = alias or {}
-        self.ghost = ghost
+    def __init__(self, chunk: ByteString, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.ghost = False
         self.chunk = chunk
+        self.fix()
+
+    def update(self, *args, **kwargs):
+        super().update(*args, **kwargs)
+        self.fix()
 
     def fix(self):
         for key, value in self.items():
             ctype = self.CUSTOM_TYPE_MAP.get(key)
-            if ctype and not isinstance(value, ctype):
+            if ctype and not isinstance(value, ctype) and issubclass(ctype, type(value)):
                 self[key] = ctype(value)
         return self
 
+    def serializable(self) -> dict:
+        result = dict(self)
+        for key, value in result.items():
+            try:
+                value: ByteStringWrapper
+                value = value.binary
+            except AttributeError:
+                continue
+            else:
+                result[key] = value
+        return result
+
+    def items(self):
+        for key, value in super().items():
+            if not is_valid_variable_name(key):
+                continue
+            yield key, value
+
     def format_str(self, spec: str, codec: str, *args, **symb) -> str:
         """
         Formats the input expression like a normal Python format string expression. Certain refinery
@@ -314,9 +362,6 @@ class LazyMetaOracle(dict):
         from .argformats import ParserError, PythonExpression
         # prevents circular import
 
-        def identity(x):
-            return x
-
         if fixup:
             for (store, it) in (
                 (args, enumerate(args)),
@@ -407,8 +452,21 @@ class LazyMetaOracle(dict):
                         'a': ascii,
                         's': str,
                         'r': repr,
-                    }.get(conversion, identity)
-                    output = converter(value)
+                        'H': lambda b: b.hex().upper(),
+                        'h': lambda b: b.hex(),
+                        'u': lambda b: b.decode('utf-16le'),
+                        'e': lambda b: b.decode('utf8', errors='backslashreplace')
+                    }.get(conversion)
+                    if converter:
+                        output = converter(value)
+                    elif modifier:
+                        output = value
+                    elif isinstance(value, CustomStringRepresentation):
+                        output = str(value)
+                    elif isbuffer(value):
+                        output = value.decode('utf8', errors='replace')
+                    else:
+                        output = value
                     output = output.__format__(modifier)
                 stream.write(output)
             return stream.getvalue()
@@ -416,25 +474,31 @@ class LazyMetaOracle(dict):
     def __contains__(self, key):
         return super().__contains__(key) or key in COMMON_PROPERTIES
 
+    def __getitem__(self, key):
+        item = super().__getitem__(key)
+        if isinstance(item, str):
+            return item.encode('utf8')
+        return item
+
     def __missing__(self, key):
         deduction = COMMON_PROPERTIES.get(key)
         if deduction is NotImplemented:
             raise KeyError(F'cannot deduce the {key} property from just the data, you have to use the cm unit.')
         if deduction:
             return self.setdefault(key, deduction(self.chunk))
-        if key in self.alias:
-            return self[self.alias[key]]
         raise KeyError(F'The meta variable {key} is unknown.')
 
 
-def metavars(chunk, *pre_populate, ghost: bool = False, alias: Optional[Dict[str, str]] = None) -> LazyMetaOracle:
+def metavars(chunk, ghost: bool = False) -> LazyMetaOracle:
     """
     This method is the main function used by refinery units to get the meta variable dictionary
     of an input chunk. This dictionary is wrapped using the `refinery.lib.meta.LazyMetaOracleFactory`
     so that access to common variables is always possible.
     """
-    alias = alias or None
-    oracle = LazyMetaOracle(chunk, ghost, alias, getattr(chunk, 'meta', {}))
-    for key in pre_populate:
-        oracle[key]
-    return oracle.fix()
+    meta: Union[dict, LazyMetaOracle] = getattr(chunk, 'meta', {})
+    if not isinstance(meta, LazyMetaOracle):
+        if not isinstance(meta, dict):
+            raise TypeError('Invalid meta type.')
+        meta = LazyMetaOracle(chunk, meta)
+    meta.ghost = ghost
+    return meta
