@@ -6,8 +6,6 @@ Implements several popular block and stream ciphers.
 import abc
 
 from typing import Iterable, Any, ByteString, Tuple
-from Crypto.Util.Padding import pad, unpad
-from Crypto.Util import Counter
 
 from ... import arg, Unit, Executable, RefineryCriticalException, RefineryPartialResult
 from ....lib.argformats import OptionFactory, extract_options
@@ -20,7 +18,7 @@ class CipherExecutable(Executable):
     key sizes that are acceptable for the represented cipher.
     """
 
-    def __new__(mcs, name, bases, nmspc, abstract=False, blocksize=1, key_sizes=None):
+    def __new__(mcs, name, bases: tuple, nmspc: dict, abstract=False, blocksize=1, key_sizes=None):
         nmspc.setdefault('blocksize', blocksize)
         nmspc.setdefault('key_sizes', key_sizes)
         return super(CipherExecutable, mcs).__new__(mcs, name, bases, nmspc, abstract=abstract)
@@ -54,8 +52,13 @@ class CipherUnit(Unit, metaclass=CipherExecutable, abstract=True):
 
 class StreamCipherUnit(CipherUnit, abstract=True):
 
-    def __init__(self, key, **keywords):
-        super().__init__(key=key, **keywords)
+    def __init__(
+        self, key,
+        stateful: arg.switch('-s', help='Do not reset the key stream while processing the chunks of one frame.') = False,
+        **keywords
+    ):
+        super().__init__(key=key, stateful=stateful, **keywords)
+        self._keystream = None
 
     @abc.abstractmethod
     def keystream(self) -> Iterable[int]:
@@ -63,13 +66,19 @@ class StreamCipherUnit(CipherUnit, abstract=True):
 
     def encrypt(self, data: bytearray) -> bytearray:
         import numpy as np
-        key = np.fromiter(
-            self.keystream(), dtype=np.uint8, count=len(data))
+        it = self._keystream or self.keystream()
+        key = np.fromiter(it, dtype=np.uint8, count=len(data))
         out = np.frombuffer(
             memoryview(data), dtype=np.uint8, count=len(data))
         out ^= key
         return out
 
+    def filter(self, chunks: Iterable):
+        if self.args.stateful:
+            self._keystream = self.keystream()
+        yield from chunks
+        self._keystream = None
+
     decrypt = encrypt
 
 
@@ -98,6 +107,7 @@ class BlockCipherUnitBase(CipherUnit, abstract=True):
         return self.args.iv
 
     def reverse(self, data: ByteString) -> ByteString:
+        from Crypto.Util.Padding import pad
         padding = self.args.padding[0]
         self.log_info('padding method:', padding)
         if padding != 'RAW':
@@ -105,6 +115,7 @@ class BlockCipherUnitBase(CipherUnit, abstract=True):
         return super().reverse(data)
 
     def process(self, data: ByteString) -> ByteString:
+        from Crypto.Util.Padding import unpad
         result = super().process(data)
         for p in self.args.padding:
             if p == 'RAW':
@@ -154,9 +165,6 @@ class StandardCipherExecutable(CipherExecutable):
 
 class StandardCipherUnit(CipherUnit, metaclass=StandardCipherExecutable):
 
-    def __init__(self, key, **keywords):
-        super().__init__(key, **keywords)
-
     def _get_cipher_instance(self, **optionals) -> Any:
         self.log_info(lambda: F'encryption key: {self.args.key.hex()}')
         return self._stdcipher_.new(key=self.args.key, **optionals)
@@ -193,6 +201,7 @@ class StandardBlockCipherUnit(BlockCipherUnitBase, StandardCipherUnit):
         if mode != 'ECB':
             iv = bytes(self.iv)
             if mode == 'CTR' and len(iv) == 16:
+                from Crypto.Util import Counter
                 counter = Counter.new(self.blocksize * 8,
                     initial_value=int.from_bytes(iv, 'big'))
                 optionals['counter'] = counter
