@@ -1,8 +1,10 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from os.path import isfile, getsize, getatime, getmtime, getctime
-from glob import iglob
+import re
+
+from pathlib import Path
 from datetime import datetime
+from typing import Iterable
 
 from ...lib.meta import metavars
 from ...lib.structures import MemoryFile
@@ -22,7 +24,10 @@ class ef(Unit):
             'patterns, the file mask can include format string expressions '
             'which will be substituted from the current meta variables.'
         )),
-        list: arg.switch('-l', help='Only lists files with metadata.'),
+        list: arg.switch('-l', help='Only lists files with metadata.') = False,
+        meta: arg.switch('-m', help=(
+            'Adds the atime, mtime, ctime, and size metadata variables.'
+        )) = False,
         size: arg.number('-s', help=(
             'If specified, files will be read in chunks of size N and each '
             'chunk is emitted as one element in the output list.'
@@ -33,7 +38,13 @@ class ef(Unit):
             'number of lines in each chunk.'
         )) = False
     ):
-        super().__init__(size=size, list=list, linewise=linewise, filenames=filenames)
+        super().__init__(
+            size=size,
+            list=list,
+            meta=meta,
+            linewise=linewise,
+            filenames=filenames
+        )
 
     def _read_chunks(self, fd):
         while True:
@@ -64,39 +75,50 @@ class ef(Unit):
                 out.seek(0)
                 out.truncate()
 
+    def glob(self, pattern: str) -> Iterable[Path]:
+        if pattern.endswith('**'):
+            pattern += '/*'
+        root = Path(next(iter(re.split(R'[\?\*\[\]]', pattern, maxsplit=1)))).parent
+        glob = str(Path(pattern).relative_to(root))
+        for match in root.glob(glob):
+            yield match
+
     def process(self, data):
         meta = metavars(data, ghost=True)
         for mask in self.args.filenames:
             mask = meta.format_str(mask, self.codec, data)
             self.log_debug('scanning for mask:', mask)
-            for filename in iglob(mask, recursive=True):
-                if not isfile(filename):
+            kwargs = dict()
+            for path in self.glob(mask):
+                if not path.is_file():
                     continue
+                if self.args.meta:
+                    stat = path.stat()
+                    kwargs.update(
+                        size=stat.st_size,
+                        atime=datetime.fromtimestamp(stat.st_atime).isoformat(' ', 'seconds'),
+                        ctime=datetime.fromtimestamp(stat.st_ctime).isoformat(' ', 'seconds'),
+                        mtime=datetime.fromtimestamp(stat.st_mtime).isoformat(' ', 'seconds')
+                    )
                 if self.args.list:
                     try:
-                        yield self.labelled(
-                            filename.encode(self.codec),
-                            size=getsize(filename),
-                            atime=datetime.fromtimestamp(getatime(filename)).isoformat(' ', 'seconds'),
-                            ctime=datetime.fromtimestamp(getctime(filename)).isoformat(' ', 'seconds'),
-                            mtime=datetime.fromtimestamp(getmtime(filename)).isoformat(' ', 'seconds'),
-                        )
+                        yield self.labelled(str(path).encode(self.codec), **kwargs)
                     except OSError:
-                        self.log_warn(F'os error while scanning: {filename}')
+                        self.log_warn(F'os error while scanning: {path!s}')
                     continue
                 try:
-                    with open(filename, 'rb') as stream:
+                    with path.open('rb') as stream:
                         if self.args.linewise:
                             yield from self._read_lines(stream)
                         elif self.args.size:
                             yield from self._read_chunks(stream)
                         else:
                             data = stream.read()
-                            self.log_info(lambda: F'reading: {filename} ({len(data)} bytes)')
-                            yield self.labelled(data, path='/'.join(filename.split('\\')))
+                            self.log_info(lambda: F'reading: {path!s} ({len(data)} bytes)')
+                            yield self.labelled(data, path=path.as_posix(), **kwargs)
                 except PermissionError:
-                    self.log_warn('permission denied:', filename)
+                    self.log_warn('permission denied:', path)
                 except FileNotFoundError:
-                    self.log_warn('file is missing:', filename)
+                    self.log_warn('file is missing:', path)
                 except Exception:
-                    self.log_warn('unknown error while reading:', filename)
+                    self.log_warn('unknown error while reading:', path)
