@@ -84,13 +84,13 @@ class peek(HexViewer):
                 metavar = metavar[:linewidth - 3] + '...'
             yield metavar
 
-    def _trydecode(self, data, codec, width):
-        remaining = linecount = self.args.lines
+    def _trydecode(self, data, codec: str, width: int, linecount: int):
+        remaining = linecount
         result = []
         if codec is None:
             from ..encoding.esc import esc
             decoded = data[:abs(width * linecount)]
-            decoded = str(decoded | -esc)
+            decoded = str(decoded | -esc(bare=True))
             for k in range(0, abs(linecount), width):
                 result.append(decoded[k:k + width])
             return result
@@ -156,10 +156,10 @@ class peek(HexViewer):
 
         if self.args.lines and data:
             if self.args.esc:
-                lines = self._trydecode(data, None, txtsize)
+                lines = self._trydecode(data, None, txtsize, metrics.line_count)
             if self.args.decode:
                 for codec in ('UTF8', 'UTF-16LE', 'UTF-16', 'UTF-16BE'):
-                    lines = self._trydecode(data, codec, txtsize)
+                    lines = self._trydecode(data, codec, txtsize, metrics.line_count)
                     if lines:
                         codec = codec
                         break
